Command line tools
==================

The pymanip package provides several command line tools, for saved experimental session
introspection and management, and for simple tests of some instruments.
These tools can be invoked from the command line using the `-m pymanip`. For example for the
inline manual,

.. code-block:: bash

    $ python -m pymanip -h

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    introspection
    instruments
    oscillo
    live_preview
    reference
